pub struct Member<'a> {
pub user_id: &'a str,
pub user_info: Option<HashMap<&'a str, &'a str>>,
}Expand description
When authenticating presence-channels, this represents a particular member of the channel. This object becomes associated with that user’s subscription.
Fields
user_id: &'a strSupply an id of the member
user_info: Option<HashMap<&'a str, &'a str>>Supply any optional information to be associated with the member